pub enum ParseError {
    Empty,
    Syntax(usize, String),
    Overflow,
    TimeUnit(usize, String),
    NegativeExponentOverflow,
    PositiveExponentOverflow,
    NegativeNumber,
    InvalidInput(String),
}
Error type emitted during the parsing

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Empty

Returned, if the input was empty.



Syntax(usize, String)

A syntax error. Syntax errors report the position (column) where it was encountered and a reason.



Overflow

Currently only used internally for overflows of the maximum Duration. TODO: Rename to positive overflow TODO: Add NegativeOverflow



TimeUnit(usize, String)

An error concerning time units. Like ParseError::Syntax the position where the error occurred is included.



NegativeExponentOverflow

The exponent exceeded the minimum negative exponent (-32768)



PositiveExponentOverflow

The exponent exceeded the maximum positive exponent (+32767)



NegativeNumber

The input number was negative. Note that numbers close to 0 (< 1e-18) are not negative but resolve to 0



InvalidInput(String)

A generic error if no other error type fits